summaryrefslogtreecommitdiffstats
path: root/konqueror/listview/konq_listviewitems.cc
diff options
context:
space:
mode:
Diffstat (limited to 'konqueror/listview/konq_listviewitems.cc')
-rw-r--r--konqueror/listview/konq_listviewitems.cc24
1 files changed, 12 insertions, 12 deletions
diff --git a/konqueror/listview/konq_listviewitems.cc b/konqueror/listview/konq_listviewitems.cc
index 3c70f1fb0..a66dbb06c 100644
--- a/konqueror/listview/konq_listviewitems.cc
+++ b/konqueror/listview/konq_listviewitems.cc
@@ -144,7 +144,7 @@ void KonqListViewItem::updateContents()
const TQString entryStr = retrieveExtraEntry( m_fileitem, numExtra );
if ( tmpColumn->type == TQVariant::DateTime )
{
- TQDateTime dt = TQDateTime::fromString( entryStr, Qt::ISODate );
+ TQDateTime dt = TQT_TQDATETIME_OBJECT(TQDateTime::fromString( entryStr, Qt::ISODate ));
setText(tmpColumn->displayInColumn,
KGlobal::locale()->formatDateTime(dt));
}
@@ -173,7 +173,7 @@ void KonqListViewItem::setActive( bool active )
if ( m_bActive == active )
return;
//#### Optimize away repaint if possible, like the iconview does?
KonqBaseListViewItem::setActive( active );
int iconSize = m_pListViewWidget->iconSize();
iconSize = iconSize ? iconSize : KGlobal::iconLoader()->currentSize( KIcon::Small ); // Default = small
@@ -203,7 +203,7 @@ void KonqListViewItem::setPixmap( int column, const TQPixmap& pm )
int newWidth = pm.isNull() ? 0 : pm.width();
int newHeight = pm.isNull() ? 0 : pm.height();
// If the height or width have changed then we're going to have to repaint
// this whole thing. Fortunately since most of the calls are coming from
// setActive() this is the uncommon case.
@@ -211,12 +211,12 @@ void KonqListViewItem::setPixmap( int column, const TQPixmap& pm )
{
setup();
widthChanged( column );
- invalidateHeight();
+ tqinvalidateHeight();
return;
}
// If we're just replacing the icon with another one its size -- i.e. a
- // "highlighted" icon, don't bother repainting the whole widget.
+ // "highlighted" icon, don't bother tqrepainting the whole widget.
TQListView *lv = m_pListViewWidget;
@@ -225,7 +225,7 @@ void KonqListViewItem::setPixmap( int column, const TQPixmap& pm )
int y = lv->itemPos( this );
int w = newWidth;
int h = height();
- lv->repaintContents( x, y, w, h );
+ lv->tqrepaintContents( x, y, w, h );
}
const TQPixmap* KonqListViewItem::pixmap( int column ) const
@@ -275,9 +275,9 @@ int KonqBaseListViewItem::compare( TQListViewItem* item, int col, bool ascending
{
if ( cInfo->type & TQVariant::DateTime ) {
const TQString entryStr1 = retrieveExtraEntry( m_fileitem, numExtra );
- TQDateTime dt1 = TQDateTime::fromString( entryStr1, Qt::ISODate );
+ TQDateTime dt1 = TQT_TQDATETIME_OBJECT(TQDateTime::fromString( entryStr1, Qt::ISODate ));
const TQString entryStr2 = retrieveExtraEntry( k->m_fileitem, numExtra );
- TQDateTime dt2 = TQDateTime::fromString( entryStr2, Qt::ISODate );
+ TQDateTime dt2 = TQT_TQDATETIME_OBJECT(TQDateTime::fromString( entryStr2, Qt::ISODate ));
return ( dt1 > dt2 ) ? 1 : ( dt1 < dt2 ) ? -1 : 0;
}
}
@@ -294,7 +294,7 @@ int KonqBaseListViewItem::compare( TQListViewItem* item, int col, bool ascending
}
}
-void KonqListViewItem::paintCell( TQPainter *_painter, const TQColorGroup & _cg, int _column, int _width, int _alignment )
+void KonqListViewItem::paintCell( TQPainter *_painter, const TQColorGroup & _cg, int _column, int _width, int _tqalignment )
{
TQColorGroup cg( _cg );
@@ -306,7 +306,7 @@ void KonqListViewItem::paintCell( TQPainter *_painter, const TQColorGroup & _cg,
cg.setColor( TQColorGroup::Text, m_pListViewWidget->itemColor() );
KListView *lv = static_cast< KListView* >( listView() );
- const TQPixmap *pm = lv->viewport()->paletteBackgroundPixmap();
+ const TQPixmap *pm = TQT_TQPIXMAP_CONST(lv->viewport()->paletteBackgroundPixmap());
if ( _column == 0 && isSelected() && !lv->allColumnsShowFocus() )
{
int newWidth = width( lv->fontMetrics(), lv, _column );
@@ -330,7 +330,7 @@ void KonqListViewItem::paintCell( TQPainter *_painter, const TQColorGroup & _cg,
_width = newWidth;
}
- KListViewItem::paintCell( _painter, cg, _column, _width, _alignment );
+ KListViewItem::paintCell( _painter, cg, _column, _width, _tqalignment );
}
void KonqListViewItem::paintFocus( TQPainter * _painter, const TQColorGroup & cg, const TQRect & _r )
@@ -421,7 +421,7 @@ KonqBaseListViewItem::~KonqBaseListViewItem()
TQRect KonqBaseListViewItem::rect() const
{
- TQRect r = m_pListViewWidget->itemRect(this);
+ TQRect r = m_pListViewWidget->tqitemRect(this);
return TQRect( m_pListViewWidget->viewportToContents( r.topLeft() ), TQSize( r.width(), r.height() ) );
}
@@ -173,7 +173,7 @@ void KonqListViewItem::setActive( bool active )
if ( m_bActive == active )
return;
- //#### Optimize away repaint if possible, like the iconview does?
+ //#### Optimize away tqrepaint if possible, like the iconview does?
KonqBaseListViewItem::setActive( active );
int iconSize = m_pListViewWidget->iconSize();
@@ -203,7 +203,7 @@ void KonqListViewItem::setPixmap( int column, const TQPixmap& pm )
int newWidth = pm.isNull() ? 0 : pm.width();
int newHeight = pm.isNull() ? 0 : pm.height();
- // If the height or width have changed then we're going to have to repaint
+ // If the height or width have changed then we're going to have to tqrepaint
// this whole thing. Fortunately since most of the calls are coming from
// setActive() this is the uncommon case.